==> green-core-1.70.1.tgz: package/components/icon/icon.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { html } from "lit";
import { property } from "lit/decorators.js";
import { unsafeHTML } from "lit/directives/unsafe-html.js";
import { GdsElement } from "../../gds-element";
import IconCSS from "./icon.style";
class GdsIcon extends GdsElement {
  constructor() {
    super(...arguments);
    this.solid = false;
    this.box = false;
    this.label = "";
  }
  render() {
    const isSebIcon = this.constructor._name === "brand-seb";
    const width = isSebIcon ? "55px" : this.width !== void 0 ? `${this.width.toString()}px` : void 0;
    const height = isSebIcon ? "24px" : this.height !== void 0 ? `${this.height.toString()}px` : "1lh";
    const viewBox = isSebIcon ? "0 0 55 24" : this.box || "0 0 24 24";
    let svgContent = `<svg
      style="height:${height};${width ? `width:${width};` : ""}"
      viewBox="${viewBox}"
      fill="none"
      xmlns="http://www.w3.org/2000/svg"
      ${this.label ? `aria-label="${this.label}"` : `aria-label="${this.constructor._name}"`}
      role="graphics-symbol"
      part="icon"
    >
      ${this.solid ? this.constructor._solidSVG : this.constructor._regularSVG}
    </svg>`;
    if (this.stroke) {
      svgContent = svgContent.replace(
        /<(path|rect|circle|ellipse|line|polyline|polygon)/g,
        `<$1 stroke-width="${this.stroke}"`
      );
    }
    return html`${unsafeHTML(svgContent)}`;
  }
}
GdsIcon.styles = [IconCSS];
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "width", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "height", 2);
__decorateClass([
  property({ type: Boolean })
], GdsIcon.prototype, "solid", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "stroke", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "box", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "label", 2);
export {
  GdsIcon
};

==> green-core-1.71.0.tgz: package/components/icon/icon.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { html } from "lit";
import { property } from "lit/decorators.js";
import { unsafeHTML } from "lit/directives/unsafe-html.js";
import { GdsElement } from "../../gds-element.js";
import IconCSS from "./icon.style";
class GdsIcon extends GdsElement {
  constructor() {
    super(...arguments);
    this.solid = false;
    this.box = false;
    this.label = "";
  }
  render() {
    const isSebIcon = this.constructor._name === "brand-seb";
    const width = isSebIcon ? "55px" : this.width !== void 0 ? `${this.width.toString()}px` : void 0;
    const height = isSebIcon ? "24px" : this.height !== void 0 ? `${this.height.toString()}px` : "1lh";
    const viewBox = isSebIcon ? "0 0 55 24" : this.box || "0 0 24 24";
    let svgContent = `<svg
      style="height:${height};${width ? `width:${width};` : ""}"
      viewBox="${viewBox}"
      fill="none"
      xmlns="http://www.w3.org/2000/svg"
      ${this.label ? `aria-label="${this.label}"` : `aria-label="${this.constructor._name}"`}
      role="graphics-symbol"
      part="icon"
    >
      ${this.solid ? this.constructor._solidSVG : this.constructor._regularSVG}
    </svg>`;
    if (this.stroke) {
      svgContent = svgContent.replace(
        /<(path|rect|circle|ellipse|line|polyline|polygon)/g,
        `<$1 stroke-width="${this.stroke}"`
      );
    }
    return html`${unsafeHTML(svgContent)}`;
  }
}
GdsIcon.styles = [IconCSS];
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "width", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "height", 2);
__decorateClass([
  property({ type: Boolean })
], GdsIcon.prototype, "solid", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "stroke", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "box", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "label", 2);
export {
  GdsIcon
};
